@@ -165,9 +165,12 @@ class Speakeasy(object):
         while self.running:
             socks = dict(self.poller.poll(1000))
             if self.recv_socket in socks and socks[self.recv_socket] == zmq.POLLIN:
-                metric = ujson.loads(self.recv_socket.recv())
-                # Put metric on metrics queue
-                self.metrics_queue.put((metric, False))
+                try:
+                    metric = ujson.loads(self.recv_socket.recv())
+                    # Put metric on metrics queue
+                    self.metrics_queue.put((metric, False))
+                except ValueError as e:
+                    logger.warn("Error receving metric: {0}".format(e))
 
             if self.cmd_socket in socks and socks[self.cmd_socket] == zmq.POLLIN:
                 cmd = ujson.loads(self.cmd_socket.recv())
